@@ -28,7 +28,7 @@ from tiddlyweb.util import binary_tiddler
 from .model import (Base, Session, sBag, sPolicy, sRecipe, sTiddler, sRevision,
         sText, sTag, sField, sCurrentRevision, sFirstRevision, sUser, sRole)
 
-__version__ = '3.0.11'
+__version__ = '3.0.12'
 
 #logging.basicConfig()
 #logging.getLogger('sqlalchemy.engine').setLevel(logging.INFO)
@@ -472,14 +472,8 @@ class Store(StorageInterface):
 
         self.session.flush()
 
-        # Do text inserts "raw" so we can use DELAYED
-        if 'mysql_engine' in sText.__table__.kwargs:
-            prefix = 'DELAYED'
-        else:
-            prefix = ''
         text_insert = (sText.__table__.insert()
-                .prefix_with(prefix).values(text=tiddler.text,
-                    revision_number=srevision.number))
+                .values(text=tiddler.text, revision_number=srevision.number))
         self.session.execute(text_insert)
 
         for tag in set(tiddler.tags):
